@@ -123,6 +123,14 @@ public class vtkDelaunay2D extends vtkPolyDataAlgorithm
   public int GetProjectionPlaneMode()
     { return GetProjectionPlaneMode_26(); }
 
+  private native long ComputeBestFittingPlane_27(vtkPointSet id0);
+  public vtkAbstractTransform ComputeBestFittingPlane(vtkPointSet id0) {
+    long temp = ComputeBestFittingPlane_27(id0);
+
+    if (temp == 0) return null;
+    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
   public vtkDelaunay2D() { super(); }
 
   public vtkDelaunay2D(long id) { super(id); }
